@@ -130,6 +130,8 @@ function enigmailBuildList(refresh) {
 
   EnigLoadKeyList(refresh, keyListObj, getSortColumn(), getSortDirection());
 
+  if (!keyListObj.keySortList) return;
+
   gKeyList = keyListObj.keyList;
   gKeySortList = keyListObj.keySortList;
 
@@ -492,7 +494,12 @@ function enigmailDeleteKey() {
     }
   }
 
-  EnigmailKeyMgmt.deleteKey(window, "0x"+keyList.join(" 0x"), deleteSecret,
+  let fprArr = [];
+  for (let j in keyList) {
+    fprArr.push("0x" + gKeyList[keyList[j]].fpr);
+  }
+
+  EnigmailKeyMgmt.deleteKey(window, fprArr.join(" "), deleteSecret,
     function(exitCode, errorMsg) {
       if (exitCode != 0) {
         EnigAlert(EnigGetString("deleteKeyFailed")+"\n\n"+errorMsg);
@@ -808,18 +815,31 @@ function enigmailExportKeys() {
     return;
   }
 
-  var exportFlags = 0;
-  if (gKeyList[keyList[0]].secretAvailable) {
-    var r=EnigLongAlert(EnigGetString("exportSecretKey"), null, EnigGetString("keyMan.button.exportPubKey"), EnigGetString("keyMan.button.exportSecKey"), ":cancel");
-    switch (r) {
-    case 1:
-      exportFlags |= nsIEnigmail.EXTRACT_SECRET_KEY;
-      break;
-    case 2:
-      return;
+  // check whether we want to export a private key anywhere in the key list
+  var secretFound = false;
+  for (var i=0; i<keyList.length && !secretFound; ++i) {
+    if (gKeyList[keyList[i]].secretAvailable) {
+      secretFound = true;
     }
   }
 
+  var exportFlags = 0;
+  if (secretFound) {
+    // double check that also the pivate keys shall be exportet
+    var r=EnigLongAlert(EnigGetString("exportSecretKey"), null,
+                        EnigGetString("keyMan.button.exportPubKey"),
+                        EnigGetString("keyMan.button.exportSecKey"),
+                        ":cancel");
+    switch (r) {
+      case 0: // export pub key only
+        break;
+      case 1: // export secret key
+        exportFlags |= nsIEnigmail.EXTRACT_SECRET_KEY;
+        break;
+      case 2: // cancel
+        return;
+      }
+  }
 
   var enigmailSvc = GetEnigmailSvc();
   if (!enigmailSvc)
@@ -844,7 +864,15 @@ function enigmailExportKeys() {
     }
   }
 
-  var outFile = EnigFilePicker(EnigGetString("exportToFile"),
+  var FilePickerLabel="";
+
+  if (exportFlags & nsIEnigmail.EXTRACT_SECRET_KEY) {
+    FilePickerLabel = EnigGetString("exportKeypairToFile");
+  }
+  else {
+    FilePickerLabel = EnigGetString("exportToFile");
+  }
+  var outFile = EnigFilePicker(FilePickerLabel,
                                "", true, "*.asc",
                                defaultFileName,
                                [EnigGetString("asciiArmorFile"), "*.asc"]);
@@ -1257,7 +1285,8 @@ function determineHiddenKeys(keyObj, showInvalidKeys, showUntrustedKeys, showOth
   return show;
 }
 
-function enigApplyFilter() {
+function enigApplyFilter()
+{
   var searchTxt=gSearchInput.value;
   var nothingFoundElem = document.getElementById("nothingFound");
   nothingFoundElem.hidePopup();
@@ -1265,40 +1294,77 @@ function enigApplyFilter() {
   var showUntrustedKeys = gShowUntrustedKeys.getAttribute("checked") == "true";
   var showOthersKeys = gShowOthersKeys.getAttribute("checked") == "true";
 
-  // skip leading 0x in case we search for a key:
-  if (searchTxt.substr(0,2).toLowerCase() == "0x") {
-    searchTxt = searchTxt.substr(2);
-  }
-
   if (!searchTxt || searchTxt.length==0) {
     showOrHideAllKeys();
     return;
   }
-  else {
-    document.getElementById("emptyTree").hidePopup();
+  document.getElementById("emptyTree").hidePopup();
+
+  // skip leading 0x in case we search for a key:
+  if (searchTxt.length > 2 && searchTxt.substr(0,2).toLowerCase() == "0x") {
+    searchTxt = searchTxt.substr(2);
   }
 
   searchTxt = searchTxt.toLowerCase();
+  searchTxt = searchTxt.replace(/^(\s*)(.*)/, "$2").replace(/\s+$/,"");  // trim spaces
+
+  // check if we search for a full fingerprint (with optional spaces every 4 letters)
+  var fpr = null;
+  if (searchTxt.length == 49) { // possible fingerprint with spaces?
+    if (searchTxt.search(/^[0-9a-f ]*$/)>=0 && searchTxt[4]==' ' && searchTxt[9]==' ' && searchTxt[14]==' '
+                                            && searchTxt[19]==' ' && searchTxt[24]==' ' && searchTxt[29]==' '
+                                            && searchTxt[34]==' ' && searchTxt[39]==' ' && searchTxt[44]==' ') {
+      fpr = searchTxt.replace(/ /g,"");
+    }
+  }
+  else if (searchTxt.length == 40) { // possible fingerprint without spaces
+    if (searchTxt.search(/^[0-9a-f ]*$/) >= 0) {
+      fpr = searchTxt;
+    }
+  }
+
   var foundResult = false;
   var node=getFirstNode();
   while (node) {
     var uid = gKeyList[node.id].userId;
-    var hideNode = true;
-    if ((uid.toLowerCase().indexOf(searchTxt) >= 0) ||
-        (node.id.toLowerCase().indexOf(searchTxt) >= 0)) {
-       if (determineHiddenKeys(gKeyList[node.id], showInvalidKeys, showUntrustedKeys, showOthersKeys)) {
-          hideNode = false;
-          foundResult = true;
-        }
+    var showNode = false;
+    if (uid.toLowerCase().indexOf(searchTxt) >= 0) {
+      showNode = true;
     }
-    for (var subUid=0; subUid < gKeyList[node.id].SubUserIds.length; subUid++) {
-      uid = gKeyList[node.id].SubUserIds[subUid].userId;
-      if (uid.toLowerCase().indexOf(searchTxt) >= 0) {
-        hideNode = false;
-        foundResult = true;
+    // does the full fingerprint (without spaces) match?
+    // - no partial match check because this is special for the collapsed spaces inside the fingerprint
+    if (showNode==false && fpr != null && gKeyList[node.id].fpr.toLowerCase() == fpr) {
+      showNode = true;
+    }
+    // does the fingerprint (partially) match?
+    if (showNode==false && gKeyList[node.id].fpr.toLowerCase().indexOf(searchTxt) >= 0) {
+      showNode = true;
+    }
+    // does a sub user (partially) match?
+    if (showNode==false) {
+      for (var subUidIdx=0; subUidIdx < gKeyList[node.id].SubUserIds.length; subUidIdx++) {
+        uid = gKeyList[node.id].SubUserIds[subUidIdx].userId;
+        if (uid.toLowerCase().indexOf(searchTxt) >= 0) {
+          showNode = true;
+        }
       }
     }
-    node.hidden=hideNode;
+    // does a sub key of (partially) match?
+    if (showNode==false) {
+      for (var subKeyIdx=0; subKeyIdx < gKeyList[node.id].subKeys.length; subKeyIdx++) {
+        subkey = gKeyList[node.id].subKeys[subKeyIdx].keyId;
+        if (subkey.toLowerCase().indexOf(searchTxt) >= 0) {
+          showNode = true;
+        }
+      }
+    }
+    // take option to show invalid/untrusted... keys into account
+    var hideNode = true;
+    if (showNode && determineHiddenKeys(gKeyList[node.id], showInvalidKeys, showUntrustedKeys, showOthersKeys)) {
+      hideNode = false;
+      foundResult = true;
+    }
+    node.hidden = hideNode;
     node = node.nextSibling;
   }
 
